// TOP_CM.v
/********************************************************************************
 Actel Corportation
 Fusion's Voltage Comparator Application Note's Design Example

 File Name:    TOP_CM.vhd
 Date:         December 2006
 Language:     Verilog

********************************************************************************
 IMPORTANT-READ THESE TERMS CAREFULLY BEFORE UTILIZING THE INFORMATION
 CONTAINED IN THIS APPLICATION NOTE. 

 NO SUPPORT/NO WARRANTY. THE DESIGN FILES AND DOCUMENTATION ARE PROVIDED
 WITHOUT SUPPORT OR WARRANTY OF ANY KIND. ACTEL IS NOT OBLIGATED TO 
 PROVIDE UPDATES, BUG FIXES, OR TECHNICAL SUPPORT AND DISCLAIMS ALL 
 WARRANTIES INCLUDING, WITHOUT LIMITATION, THE WARRANTIES OF MERCHANTABILITY,
 FITNESS FOR A PARTICULAR PURPOSE, AND WARRANTIES OF NON-INFRINGEMENT OF THE
 RIGHTS OF THIRD PARTIES (INCLUDING, WITHOUT LIMITATION, RIGHTS UNDER PATENT,
 COPYRIGHT, TRADE SECRET, OR OTHER INTELLECTUAL PROPERTY RIGHTS).  RECIPIENT
 ACCEPTS THE APPLICATION NOTE DESIGN FILES AND DOCUMENTATION IN "AS-IS"
 CONDITION.
*******************************************************************************/

// This module uses internal voltage regulator of Fusion devices (PUB and SPARE ports are related
// to the voltage regulator. The usage is optional. Users can use externally supplied 1.5V to power up
// the FPGA core.
`define WIDTH_OUTPUT 12

module TOP_CM ( 
SYSCLK, SYSRSTn, VAREF, AV0, AC0, AV1, AC1, AV2, AC2, AV3, AC3, AV4, AC4, AV5, AC5, 
Diff0, Diff1, Diff2, Diff3, Diff4, Diff5, Latest_Update, New_Measurement,
PUB, SPARE);

input SYSCLK, SYSRSTn; //10MHz system clock and active low system reset
inout VAREF; 
input AV0 ; // P port input for Diff measurement channel 0
input AC0 ; // N port input for Diff measurement channel 0 
input AV1 ; // P port input for Diff measurement channel 1
input AC1 ; // N port input for Diff measurement channel 1
input AV2 ; // P port input for Diff measurement channel 2
input AC2 ; // N port input for Diff measurement channel 2
input AV3 ; // P port input for Diff measurement channel 3
input AC3 ; // N port input for Diff measurement channel 3
input AV4 ; // P port input for Diff measurement channel 4
input AC4 ; // N port input for Diff measurement channel 4
input AV5 ; // P port input for Diff measurement channel 5
input AC5 ; // N port input for Diff measurement channel 5 
output [`WIDTH_OUTPUT-1:0] Diff0; // differential measurement results
output [`WIDTH_OUTPUT-1:0] Diff1; // differential measurement results
output [`WIDTH_OUTPUT-1:0] Diff2; // differential measurement results
output [`WIDTH_OUTPUT-1:0] Diff3; // differential measurement results
output [`WIDTH_OUTPUT-1:0] Diff4; // differential measurement results
output [`WIDTH_OUTPUT-1:0] Diff5; // differential measurement results
output [2:0] Latest_Update; //index of latest measured channel
output New_Measurement;
input PUB;
output SPARE;

wire ASSC_DONE, DATAVALID; 
wire[`WIDTH_OUTPUT-1:0] ADC_RESULT; 
wire [4:0] ADC_CHNUMBER; 
wire [8:0] INIT_ADDR, INIT_DATA;
wire INIT_ACM_WEN, INIT_DONE, INIT_ASSC_WEN, INIT_EV_WEN, INIT_TR_WEN;
wire FPGAGOOD;


AB_CM AB_CM_isnt (
  .SYS_CLK(SYS_CLK), .SYS_RESET(SYS_RESET), .VAREF(VAREF), .DATAVALID(DATAVALID), .AV0(AV0), .AV1(AV1), .AV2(AV2), 
  .AV3(AV3), .AV4(AV4), .AV5(AV5), .AC0(AC0), .AC1(AC1), .AC2(AC2), .AC3(AC3), .AC4(AC4), .AC5(AC5), .ASSC_DONE(ASSC_DONE), 
  .ASSC_WAIT(), .ASSC_CHSAT(), .ASSC_CHLATD(), .INIT_ADDR (INIT_ADDR ), .INIT_DATA(INIT_DATA), 
  .INIT_ACM_WEN(INIT_ACM_WEN), .INIT_ASSC_WEN(INIT_ASSC_WEN), .INIT_EV_WEN(INIT_EV_WEN), .INIT_TR_WEN(INIT_TR_WEN), 
  .INIT_DONE(INIT_DONE), .ADC_RESULT(ADC_RESULT), .ADC_CHNUMBER(ADC_CHNUMBER));


NVM_CM NVM_CM_inst
    (.INIT_CLK(SYSCLK),
     .SYS_RESET(SYSRSTn),
     .INIT_POWER_UP(1'b1),
     .INIT_DONE(INIT_DONE),
     .INIT_DATA(INIT_DATA),
     .INIT_ADDR(INIT_ADDR),
     .INIT_ACM_WEN(INIT_ACM_WEN),
     .INIT_ASSC_WEN(INIT_ASSC_WEN),
     .INIT_EV_WEN(INIT_EV_WEN),
     .INIT_TR_WEN(INIT_TR_WEN));

VR_INT VR_INT_inst (.PUB(PUB), .VRPU(1'b0), .FPGAGOOD(FPGAGOOD), .PUCORE());

assign SPARE = FPGAGOOD;


COMP_SM COMP_SM_inst (
  .SYSCLK(SYSCLK),.RESETn(SYSRSTn),.DATAVALID(ASSC_DONE), .ADC_CHNUMBER(ADC_CHNUMBER),
  .ADC_RESULT(ADC_RESULT), .INIT_DONE(INIT_DONE), .Diff_0(Diff0), .Diff_1(Diff1),
  .Diff_2(Diff2), .Diff_3(Diff3), .Diff_4(Diff4), .Diff_5(Diff5), .Latest_Update(Latest_Update),
  .New_Measurement(New_Measurement));

endmodule

